DaiInterconnectElementState

Struct DaiInterconnectElementState 

pub struct DaiInterconnectElementState {
    pub plug_state: Option<PlugState>,
    pub external_delay: Option<i64>,
    /* private fields */
}
State for an Element with ElementType DAI_INTERCONNECT.

Fields

plug_state: Option<PlugState>

The plug state for this DAI interconnect.

Required.

external_delay: Option<i64>

The driver’s best estimate of the external delay beyond this DAI endpoint, as the pipeline is currently configured.

external_delay must be taken into account by the client when determining the requirements for minimum lead time (during playback) and minimum capture delay (during capture).

If not included, external_delay is unknown; the client may treat it however it chooses (e.g. consider it zero or some other duration, autodetect it, etc).

Optional. If specified, must be non-negative.